summaryrefslogtreecommitdiffstats
path: root/chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h
diff options
context:
space:
mode:
Diffstat (limited to 'chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h')
-rw-r--r--chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h37
1 files changed, 18 insertions, 19 deletions
diff --git a/chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h b/chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h
index 6269af8d7e0..5a0434563aa 100644
--- a/chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h
+++ b/chromium/third_party/WebKit/Source/core/rendering/RenderTextControl.h
@@ -34,20 +34,21 @@ public:
virtual ~RenderTextControl();
HTMLTextFormControlElement* textFormControlElement() const;
- virtual PassRefPtr<RenderStyle> createInnerTextStyle(const RenderStyle* startStyle) const = 0;
+ virtual PassRefPtr<RenderStyle> createInnerEditorStyle(const RenderStyle* startStyle) const = 0;
protected:
RenderTextControl(HTMLTextFormControlElement*);
- // This convenience function should not be made public because innerTextElement may outlive the render tree.
- HTMLElement* innerTextElement() const;
+ // This convenience function should not be made public because
+ // innerEditorElement may outlive the render tree.
+ HTMLElement* innerEditorElement() const;
int scrollbarThickness() const;
- void adjustInnerTextStyle(RenderStyle* textBlockStyle) const;
+ void adjustInnerEditorStyle(RenderStyle* textBlockStyle) const;
- virtual void styleDidChange(StyleDifference, const RenderStyle* oldStyle);
+ virtual void styleDidChange(StyleDifference, const RenderStyle* oldStyle) OVERRIDE;
- void hitInnerTextElement(HitTestResult&, const LayoutPoint& pointInContainer, const LayoutPoint& accumulatedOffset);
+ void hitInnerEditorElement(HitTestResult&, const LayoutPoint& pointInContainer, const LayoutPoint& accumulatedOffset);
int textBlockLogicalWidth() const;
int textBlockLogicalHeight() const;
@@ -59,9 +60,9 @@ protected:
virtual LayoutUnit preferredContentLogicalWidth(float charWidth) const = 0;
virtual LayoutUnit computeControlLogicalHeight(LayoutUnit lineHeight, LayoutUnit nonContentHeight) const = 0;
- virtual void updateFromElement();
+ virtual void updateFromElement() OVERRIDE;
virtual void computeLogicalHeight(LayoutUnit logicalHeight, LayoutUnit logicalTop, LogicalExtentComputedValues&) const OVERRIDE;
- virtual RenderObject* layoutSpecialExcludedChild(bool relayoutChildren, SubtreeLayoutScope&);
+ virtual RenderObject* layoutSpecialExcludedChild(bool relayoutChildren, SubtreeLayoutScope&) OVERRIDE;
// We need to override this function because we don't want overflow:hidden on an <input>
// to affect the baseline calculation. This is necessary because we are an inline-block
@@ -69,20 +70,19 @@ protected:
virtual int inlineBlockBaseline(LineDirectionMode direction) const OVERRIDE { return lastLineBoxBaseline(direction); }
private:
- virtual const char* renderName() const { return "RenderTextControl"; }
- virtual bool isTextControl() const { return true; }
- virtual bool supportsPartialLayout() const OVERRIDE { return false; }
- virtual void computeIntrinsicLogicalWidths(LayoutUnit& minLogicalWidth, LayoutUnit& maxLogicalWidth) const OVERRIDE;
- virtual void computePreferredLogicalWidths() OVERRIDE;
- virtual void removeLeftoverAnonymousBlock(RenderBlock*) { }
- virtual bool avoidsFloats() const { return true; }
- virtual bool canHaveGeneratedChildren() const OVERRIDE { return false; }
+ virtual const char* renderName() const OVERRIDE { return "RenderTextControl"; }
+ virtual bool isTextControl() const OVERRIDE FINAL { return true; }
+ virtual void computeIntrinsicLogicalWidths(LayoutUnit& minLogicalWidth, LayoutUnit& maxLogicalWidth) const OVERRIDE FINAL;
+ virtual void computePreferredLogicalWidths() OVERRIDE FINAL;
+ virtual void removeLeftoverAnonymousBlock(RenderBlock*) OVERRIDE FINAL { }
+ virtual bool avoidsFloats() const OVERRIDE FINAL { return true; }
+ virtual bool canHaveGeneratedChildren() const OVERRIDE FINAL { return false; }
virtual void addChild(RenderObject* newChild, RenderObject* beforeChild = 0) OVERRIDE FINAL;
- virtual void addFocusRingRects(Vector<IntRect>&, const LayoutPoint& additionalOffset, const RenderLayerModelObject* paintContainer = 0) OVERRIDE;
+ virtual void addFocusRingRects(Vector<IntRect>&, const LayoutPoint& additionalOffset, const RenderLayerModelObject* paintContainer = 0) OVERRIDE FINAL;
- virtual bool canBeProgramaticallyScrolled() const { return true; }
+ virtual bool canBeProgramaticallyScrolled() const OVERRIDE FINAL { return true; }
};
DEFINE_RENDER_OBJECT_TYPE_CASTS(RenderTextControl, isTextControl());
@@ -104,7 +104,6 @@ public:
}
virtual int firstLineBoxBaseline() const OVERRIDE { return RenderBlock::firstLineBoxBaseline(); }
virtual int inlineBlockBaseline(LineDirectionMode direction) const OVERRIDE { return lastLineBoxBaseline(direction); }
- virtual bool supportsPartialLayout() const OVERRIDE { return false; }
};